# OctoPrintPrintJobPayload

Serialize OctoPrint print job status events: https://docs.octoprint.org/en/master/events/index.html?highlight=events#printing

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**path** | **str** |  | 
**origin** | **str** |  | 
**size** | **int** |  | [optional] 
**time** | **float** |  | [optional] 
**position** | **dict(str, object)** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


